package com.fs.live.service;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.IService;
import com.fs.live.domain.LiveQuestion;

/**
 * 问答Service接口
 * 
 * @author fs
 * @date 2025-01-17
 */
public interface ILiveQuestionService extends IService<LiveQuestion>
{
    /**
     * 查询问答
     * 
     * @param questionId 问答主键
     * @return 问答
     */
    public LiveQuestion selectLiveQuestionByQuestionId(Long questionId);

    /**
     * 查询问答列表
     * 
     * @param liveQuestion 问答
     * @return 问答集合
     */
    public List<LiveQuestion> selectLiveQuestionList(LiveQuestion liveQuestion);

    /**
     * 新增问答
     * 
     * @param liveQuestion 问答
     * @return 结果
     */
    public int insertLiveQuestion(LiveQuestion liveQuestion);

    /**
     * 修改问答
     * 
     * @param liveQuestion 问答
     * @return 结果
     */
    public int updateLiveQuestion(LiveQuestion liveQuestion);

    /**
     * 批量删除问答
     * 
     * @param questionIds 需要删除的问答主键集合
     * @return 结果
     */
    public int deleteLiveQuestionByQuestionIds(Long[] questionIds);

    /**
     * 删除问答信息
     * 
     * @param questionId 问答主键
     * @return 结果
     */
    public int deleteLiveQuestionByQuestionId(Long questionId);
}
